@@ -1,3 +1,3 @@
-#from ftscraper import api
 from ftscraper.api import search
+from ftscraper.api import select_fund
 from ftscraper.api import search_select_fund
\ No newline at end of file
