@@ -30,4 +30,20 @@ def etf_or_fund(sec_name, search_results):
     score = {'etf':np.mean(scores['etf']),'fund':np.mean(scores['fund'])}
     max_score = max(score.items(), key=operator.itemgetter(1))[0]
 
-    return max_score
\ No newline at end of file
+    return max_score
+
+def filter_by_currency(search_results):
+
+    currencies = ['usd','eur','gbp','aus']
+
+    results = []
+    for currency in currencies:
+        for search in search_results:
+            if search.symbol.split(':')[-1].lower() == currency:
+                results.append(search)
+        
+        if len(results) > 0:
+            break
+    
+    return results
+    
